# pkg_wordslookup

This package will look the instances of a specific word provided as an input inside a file also provided as an input. The package will give the amount of times the word is in the file and it will print the line in which the word is placed

## Installation

```bash
$ pip install pkg_wordslookup
```

## Usage

- TODO

## Contributing

Interested in contributing? Check out the contributing guidelines. Please note that this project is released with a Code of Conduct. By contributing to this project, you agree to abide by its terms.

## License

`pkg_wordslookup` was created by Gabriel Coronel. It is licensed under the terms of the MIT license.

## Credits

`pkg_wordslookup` was created with [`cookiecutter`](https://cookiecutter.readthedocs.io/en/latest/) and the `py-pkgs-cookiecutter` [template](https://github.com/py-pkgs/py-pkgs-cookiecutter).
